@@ -1,16 +1,16 @@
 <?php
-/* $Id: french-iso-8859-15.inc.php 9380 2006-08-30 10:43:15Z nijel $ */
+/* $Id: french-iso-8859-1.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
-$charset = 'iso-8859-15';
+$charset = 'iso-8859-1';
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('o', 'Kio', 'Mio', 'Gio', 'Tio', 'Pio', 'Eio');
 
 $mysql_5_0_doc_lang = 'fr';
 
-$day_of_week = array('Dimanche', 'Lundi', 'Mardi', 'Mercredi', 'Jeudi', 'Vendredi', 'Samedi');
+$day_of_week = array('Dim', 'Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam');
 $month = array('Janvier', 'Fvrier', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Aot', 'Septembre', 'Octobre', 'Novembre', 'Dcembre');
 // Voir http://www.php.net/manual/en/function.strftime.php pour la variable
 // ci-dessous
@@ -19,18 +19,15 @@ $datefmt = '%A %d %B %Y  %H:%M';
 $timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';
 
 $strAbortedClients = 'Arrts prmaturs';
-$strAbsolutePathToDocSqlDir = 'Veuillez entrer le chemin absolu du rpertoire docSQL sur le serveur web';
 $strAccessDenied = 'Accs refus';
 $strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas cr de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
-$strAccessDeniedExplanation = 'phpMyAdmin a tent de se connecter au serveur MySQL, et le serveur a rejet la connexion. Veuillez vrifier les valeurs de "host", "username" et "password" dans config.inc.php et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
+$strAccessDeniedExplanation = 'phpMyAdmin a tent de se connecter au serveur MySQL, et le serveur a rejet la connexion. Veuillez vrifier les valeurs de "host", "username" et "password" dans votre configuration et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
 $strAddClause = 'Ajouter %s';
 $strAddConstraints = 'Inclure les contraintes de cls trangres';
 $strAddDeleteColumn = 'Ajouter/effacer x colonne(s)';
 $strAddDeleteRow = 'Ajouter/effacer x ligne(s)';
-$strAddedColumnComment = 'Commentaire ajout pour la colonne';
-$strAddedColumnRelation = 'Relation ajoute pour la colonne';
 $strAddFields = 'Ajouter %s champ(s)';
 $strAddHeaderComment = 'Commentaires mis en en-tte (\\n spare les lignes)';
 $strAddIntoComments = 'Inclure sous forme de commentaires';
@@ -38,7 +35,7 @@ $strAddNewField = 'Ajouter un champ';
 $strAddPrivilegesOnDb = 'Ajouter des privilges sur cette base de donnes';
 $strAddPrivilegesOnTbl = 'Ajouter des privilges sur cette table';
 $strAddSearchConditions = 'Critres de recherche (pour l\'nonc "where"):';
-$strAddToIndex = 'Ajouter  la clef&nbsp;%s&nbsp;colonne(s)';
+$strAddToIndex = 'Ajouter  l\'index&nbsp;%s&nbsp;colonne(s)';
 $strAddUser = 'Ajouter un utilisateur';
 $strAddUserMessage = 'Vous avez ajout un utilisateur';
 $strAdministration = 'Administration';
@@ -55,6 +52,7 @@ $strAlterOrderBy = '<b>Ordonner</b> la table par';
 $strAnalyzeTable = 'Analyser la table';
 $strAnd = 'et';
 $strAndThen = 'et ensuite';
+$strAngularLinks = 'Liens angulaires';
 $strAnIndex = 'Un index a t ajout sur %s';
 $strAnyHost = 'Tout serveur';
 $strAny = 'N\'importe quel';
@@ -67,7 +65,6 @@ $strAscending = 'Croissant';
 $strAtBeginningOfTable = 'En dbut de table';
 $strAtEndOfTable = 'En fin de table';
 $strAttr = 'Attributs';
-$strAutodetect = 'Dtection automatique';
 $strAutomaticLayout = 'Mise en page automatique';
 
 $strBack = 'Retour';
@@ -107,12 +104,13 @@ $strBzError = 'phpMyAdmin n\'a pu compresser le fichier export en raison d\'une
 $strBzip = '"bzipp"';
 
 $strCalendar = 'Calendrier';
+$strCancel = 'Annuler';
 $strCanNotLoadExportPlugins = 'Erreur lors du chargement des modules d\'exportation!';
 $strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation, veuillez vrifier votre installation!';
 $strCannotLogin = 'Connexion au serveur MySQL non permise';
 $strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vrifier votre configuration de PHP';
 $strCantLoadRecodeIconv = 'Erreur lors du chargement de l\'extension iconv ou recode, utilise pour convertir le jeu de caractres; veuillez activer l\'une de ces extensions dans PHP, ou dsactiver la conversion des jeux de caractres dans phpMyAdmin';
-$strCantRenameIdxToPrimary = 'La clef ne peut tre renomme PRIMARY&nbsp;!';
+$strCantRenameIdxToPrimary = 'L\'index ne peut tre renomm PRIMARY!';
 $strCantUseRecodeIconv = 'Erreur lors de l\'utilisation de iconv, libiconv et recode_string, alors que ces extensions semblent charges. Veuillez vrifier votre configuration de PHP.';
 $strCardinality = 'Cardinalit';
 $strCaseInsensitive = 'insensible  la casse';
@@ -155,6 +153,7 @@ $strConnectionError = 'Connexion impossible: rglages incorrects.';
 $strConnections = 'Connexions';
 $strConstraintsForDumped = 'Contraintes pour les tables exportes';
 $strConstraintsForTable = 'Contraintes pour la table';
+$strControluserFailed = 'La connexion au "controluser" tel que dfini dans votre configuration a chou.';
 $strCookiesRequired = 'Vous devez accepter les cookies pour poursuivre.';
 $strCopy = 'Copier';
 $strCopyDatabaseOK = 'La base de donnes %s a t copie sur %s';
@@ -164,12 +163,14 @@ $strCopyTableSameNames = 'On ne peut copier la table sur elle-mme!';
 $strCouldNotKill = 'phpMyAdmin n\'a pu liminer le processus %s. Il tait probablement dj ferm.';
 $strCreate = 'Crer';
 $strCreateDatabaseBeforeCopying = 'Faire CREATE DATABASE avant la copie';
-$strCreateIndex = 'Crer une clef sur&nbsp;%s&nbsp;colonne(s)';
-$strCreateIndexTopic = 'Crer un nouvelle clef';
+$strCreateIndex = 'Crer un index sur&nbsp;%s&nbsp;colonne(s)';
+$strCreateIndexTopic = 'Crer un nouvel index';
 $strCreateNewDatabase = 'Crer une base de donnes';
 $strCreateNewTable = '<b>Crer une nouvelle table</b> sur la base %s';
 $strCreatePage = 'Crer une page';
 $strCreatePdfFeat = 'Gnration de schmas en PDF';
+$strCreateRelation = 'Nouvelle relation';
+$strCreateTable  = 'Nouvelle table';
 $strCreateUserDatabase = 'Base de donnes pour cet utilisateur';
 $strCreateUserDatabaseName = 'Crer une base portant son nom et donner  cet utilisateur tous les privilges sur cette base';
 $strCreateUserDatabaseNone = 'Aucune';
@@ -178,8 +179,6 @@ $strCreationDates = 'Dates de cration/modification/vrification';
 $strCriteria = 'Critre';
 $strCroatian = 'croate';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Options CSV';
-$strCSVOptions = 'Options CSV';
 $strCyrillic = 'cyrillique';
 $strCzechSlovak = 'tchque-slovaque';
 $strCzech = 'tchque';
@@ -189,7 +188,6 @@ $strDatabase = 'Base de donnes';
 $strDatabaseEmpty = 'Le nom de la base de donnes est vide!';
 $strDatabaseExportOptions = 'Options d\'exportation';
 $strDatabaseHasBeenDropped = 'La base de donnes %s a t efface.';
-$strDatabaseNoTable = 'Cette base de donnes ne contient aucune table!';
 $strDatabases = 'Bases de donnes';
 $strDatabasesDropped = '%s bases de donnes ont t supprimes.';
 $strDatabasesStatsDisable = 'Dsactiver les statistiques';
@@ -202,15 +200,7 @@ $strDataOnly = 'Donnes seulement';
 $strDataPages = 'Pages contenant des donnes';
 $strDBComment = '<b>Commentaire</b> sur la base de donnes: ';
 $strDBCopy = 'Copier la base de donnes vers';
-$strDBGContext = 'Contexte';
-$strDBGContextID = 'Identificateur de contexte';
-$strDBGHits = 'Occurences';
-$strDBGLine = 'Ligne';
-$strDBGMaxTimeMs = 'Dure maximum, ms';
-$strDBGMinTimeMs = 'Dure minimum, ms';
-$strDBGModule = 'Module';
-$strDBGTimePerHitMs = 'Dure/Occurence, ms';
-$strDBGTotalTimeMs = 'Dure totale, ms';
+$strDbIsEmpty = 'La base de donnes semble vide!';
 $strDbPrivileges = 'Privilges spcifiques  une base de donnes';
 $strDBRename = '<b>Changer le nom</b> de la base de donnes pour';
 $strDbSpecific = 'spcifique  cette base de donnes';
@@ -225,12 +215,16 @@ $strDeleted = 'L\'enregistrement a t effac';
 $strDeletedRows = 'Nombre d\'enregistrements effacs :';
 $strDelete = 'Effacer';
 $strDeleteNoUsersSelected = 'Aucun utilisateur n\'a t choisi en vue de le dtruire!';
+$strDeleteRelation = 'Effacer la relation';
 $strDeleting = 'Destruction de %s';
 $strDelimiter = 'Dlimiteur';
 $strDelOld = 'Cette page fait rfrence  des tables qui n\'existent plus. Voulez-vous effacer ces rfrences?';
 $strDescending = 'Dcroissant';
 $strDescription = 'Description';
+$strDesigner = 'Concepteur';
+$strDesignerHelpDisplayField = 'Le champ  afficher est montr en rose. Pour indiquer qu\'un champ est ou n\'est plus le champ  afficher, cliquer l\'icne "Champ  afficher", puis cliquer sur le nom de champ appropri.';
 $strDictionary = 'dictionnaire';
+$strDirectLinks = 'Liens directs';
 $strDirtyPages = 'Pages modifies';
 $strDisabled = 'dsactiv';
 $strDisableForeignChecks = 'Dsactiver la vrification des cls trangres';
@@ -238,6 +232,7 @@ $strDisplayFeat = 'Affichage infobulle';
 $strDisplayOrder = 'Ordre d\'affichage :';
 $strDisplayPDF = '<b>Afficher le schma</b> en PDF';
 $strDoAQuery = 'Recherche par valeur (passepartout: "%")';
+$strDocSQL = 'DocSQL';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Voulez-vous vraiment effectuer ';
 $strDropDatabaseStrongWarning = 'Vous tes sur le point de DTRUIRE une base de donnes!';
@@ -267,15 +262,19 @@ $strEnglish = 'anglais';
 $strEnglishPrivileges = ' Veuillez noter que les noms de privilges sont exprims en anglais';
 $strError = 'Erreur';
 $strErrorInZipFile = 'Erreur rencontre dans l\'archive ZIP :';
+$strErrorRelationAdded = 'Erreur: relation non ajoute.';
+$strErrorRelationExists = 'Erreur: relation dj existante.';
 $strErrorRenamingTable = 'Erreur lors du renommage de %1$s en %2$s';
+$strErrorSaveTable = 'Erreur lors de la sauvegarde des coordonnes Concepteur.';
 $strEscapeWildcards = 'Prfixer avec \ les passepartouts _ et % pour un usage littral';
 $strEsperanto = 'Espranto';
 $strEstonian = 'estonien';
+$strEvent = 'vnement';
 $strExcelEdition = 'Excel en version';
-$strExcelOptions = 'Options Excel';
 $strExecuteBookmarked = 'Excuter la requte en signets';
 $strExplain = 'Expliquer SQL';
 $strExport = 'Exporter';
+$strExportImportToScale = 'Exporter/Importer  l\'chelle';
 $strExportMustBeFile = 'Ce choix d\'exportation doit tre sauvegard dans un fichier!';
 $strExtendedInserts = 'Insertions tendues';
 $strExtra = 'Extra';
@@ -283,8 +282,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Tentatives choues';
 $strField = 'Champ';
 $strFieldHasBeenDropped = 'Le champ %s a t effac';
+$strFieldInsertFromFileTempDirNotExists = 'Erreur lors du dplacement du fichier tlcharg, voir FAQ 1.11';
 $strFields = 'Champs';
-$strFieldsEmpty = 'Il faut indiquer le nombre de champs';
 $strFieldsEnclosedBy = 'Champs entours par';
 $strFieldsEscapedBy = 'Caractre spcial';
 $strFieldsTerminatedBy = 'Champs termins par';
@@ -296,6 +295,7 @@ $strFileNameTemplateDescriptionServer = 'nom de serveur';
 $strFileNameTemplateDescriptionTable = 'nom de table';
 $strFileNameTemplate = 'Modle de nom de fichier';
 $strFileNameTemplateRemember = 'se souvenir du modle';
+$strFiles = 'Fichiers';
 $strFileToImport = 'Fichier  importer';
 $strFixed = 'fixe';
 $strFlushPrivilegesNote = 'Note: phpMyAdmin obtient la liste des privilges directement  partir des tables MySQL. Le contenu de ces tables peut tre diffrent des privilges effectifs, si des changements manuels ont t apports. Dans ce cas, vous devriez %srecharger les privilges%s avant de continuer.';
@@ -303,6 +303,7 @@ $strFlushQueryCache = 'Vider la cache des requtes';
 $strFlushTable = 'Recharger la table ("FLUSH")';
 $strFlushTables = 'Fermer toutes les tables';
 $strFontSize = 'Taille du texte';
+$strForeignKeyError = 'Erreur lors de la cration de la cl trangre (vrifiez les types de donnes';
 $strFormat = 'format';
 $strFormEmpty = 'Formulaire incomplet !';
 $strFreePages = 'Pages libres';
@@ -330,38 +331,38 @@ $strHasBeenAltered = 'a t modifi(e).';
 $strHasBeenCreated = 'a t cr(e).';
 $strHaveToShow = 'Vous devez choisir au moins une colonne  afficher';
 $strHebrew = 'hbreu';
-$strHexForBinary = 'Encoder les champs binaires en hexadcimal';
+$strHelp = 'Aide';
+$strHexForBLOB = 'Utiliser l\'hexadecimal pour les BLOB';
+$strHide         = 'Cacher';
+$strHideShowAll = 'Cacher/montrer tout';
+$strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
 $strHome = 'Accueil';
 $strHomepageOfficial = 'Site officiel de phpMyAdmin';
 $strHostEmpty = 'Le nom de serveur est vide';
 $strHost = 'Serveur';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Options d\'exportation Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Options d\'exportation Microsoft Word 2000';
 $strHungarian = 'hongrois';
 
 $strIcelandic = 'islandais';
 $strId = 'ID';
 $strIdxFulltext = 'Texte entier';
+$strIEUnsupported = 'Fonction non disponible sous Internet Explorer.';
 $strIgnoreDuplicates = 'Ignorer les doublons';
 $strIgnore = 'Ignorer';
 $strIgnoreInserts = 'Ignorer les erreurs de doublons (INSERT IGNORE)';
-$strIgnoringFile = 'Fichier %s ignor';
-$strImportDocSQL = 'Importer des fichiers docSQL';
+$strImportExportCoords = 'Importer/Exporter les coordonnes pour le schma PDF';
 $strImportFiles = 'Importe les fichiers';
 $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
 $strImportSuccessfullyFinished = 'L\'importation s\'est termine avec succs, %d requtes excutes.';
 $strIndexes = 'Index';
+$strIndexesSeemEqual = 'Les index suivants semblent quivalents, vous devriez en liminer un.';
 $strIndexHasBeenDropped = 'L\'index %s a t effac';
 $strIndex = 'Index';
-$strIndexName = 'Nom de la clef&nbsp;:';
-$strIndexType = 'Type de clef&nbsp;:';
-$strIndexWarningMultiple = 'Plus d\'un index de type %s existe pour la colonne `%s`';
-$strIndexWarningPrimary = 'La colonne `%s` ne devrait pas faire partie  la fois d\'une cl primaire et d\'une cl index';
+$strIndexName = 'Nom de l\'index&nbsp;:';
+$strIndexType = 'Type d\'index&nbsp;:';
 $strIndexWarningTable = 'Il y a des problmes avec les index de la table `%s`';
-$strIndexWarningUnique = 'La colonne `%s` ne devrait pas faire partie  la fois d\'une cl unique et d\'une cl index';
 $strInnoDBAutoextendIncrement = 'Auto-croissant: Taille de l\'incrment';
 $strInnoDBAutoextendIncrementDesc = 'La valeur de l\'incrment lors de l\'agrandissement du fichier auto-croissant lorsqu\'il devient plein.';
 $strInnoDBBufferPoolSizeDesc = 'La taille de la mmoire-tampon utilise par InnoDB pour les oprations d\'antmoire sur les donnes et les index.';
@@ -370,6 +371,7 @@ $strInnoDBDataFilePath = 'Fichiers de donnes';
 $strInnoDBDataHomeDirDesc = 'Le chemin du rpertoire pour tous les fichiers de donnes InnoDB.';
 $strInnoDBDataHomeDir = 'Rpertoire des donnes';
 $strInnoDBPages = 'pages';
+$strInnoDBRelationAdded = 'Relation InnoDB ajoute';
 $strInnodbStat = 'tat InnoDB';
 $strInsecureMySQL = 'Votre fichier de configuration fait rfrence  l\'utilisateur root sans mot de passe, ce qui correspond  la valeur par dfaut de MySQL.  Votre serveur MySQL est donc ouvert aux intrusions, et vous devriez corriger ce problme de scurit.';
 $strInsertAsNewRow = 'Sauvegarder un nouvel enregistrement';
@@ -377,6 +379,7 @@ $strInsertedRowId = 'Identifiant de l\'enregistrement insr:';
 $strInsertedRows = 'Nombre d\'enregistrements insrs :';
 $strInsert = 'Insrer';
 $strInternalNotNecessary = '* Si une relation existe dans InnoDB, il n\'est pas ncessaire de la dfinir dans les relations internes.';
+$strInternalRelationAdded = 'Relation interne ajoute';
 $strInternalRelations = 'Relations internes';
 $strInUse = 'utilis';
 $strInvalidAuthMethod = 'Le fichier de configuration contient un type d\'authentification invalide :';
@@ -402,12 +405,12 @@ $strJustDelete = 'Seulement effacer les utilisateurs des tables de privilges.';
 
 $strKeepPass = 'Conserver le mot de passe';
 $strKeyCache = 'Cache des cls';
-$strKeyname = 'Nom de la cl';
+$strKeyname = 'Nom de l\'index';
 $strKill = 'Supprimer';
+$strKnownExternalBug = 'La fonctionnalit %s est affecte par une anomalie connue, voir %s';
 $strKorean = 'coren';
 
 $strLandscape = 'Paysage';
-$strLanguageFileNotFound = 'Fichier de langue "%1$s" inexistant.';
 $strLanguage = 'Langue';
 $strLanguageUnknown = 'Langue inconnue: %1$s.';
 $strLatchedPages = 'Pages verrouilles';
@@ -418,11 +421,9 @@ $strLatexContinued = '(suite)';
 $strLatexIncludeCaption = 'Inclure les sous-titres';
 $strLatexLabel = 'Cl de l\'tiquette';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Options LaTeX';
 $strLatexStructure = 'Structure de la table __TABLE__';
 $strLatvian = 'letton';
 $strLDI = 'CSV via LOAD DATA';
-$strLDIImportOptions = 'Options pour l\'importation CSV via LOAD DATA';
 $strLDILocal = 'Utiliser l\'option LOCAL';
 $strLengthSet = 'Taille/Valeurs*';
 $strLimitNumRows = 'Nombre d\'enregistrements par page';
@@ -451,14 +452,15 @@ $strMIME_description = 'Description';
 $strMIME_MIMEtype = 'Type MIME';
 $strMIME_nodescription = 'Aucune description n\'est disponible pour cette transformation.<br />Veuillez demander  son auteur, des dtails sur %s.';
 $strMIME_transformation_note = 'La %sdescription des transformations%s explique les transformations possibles en fonction des types MIME.';
-$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\',\'b\',\'c\'...<br />Si vous devez entrer un caractre ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le prcder du caractre d\'chappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\', 100, b,\'c\'...<br />Si vous devez entrer un caractre ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le prcder du caractre d\'chappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Options de transformation';
 $strMIME_transformation = 'Transformation';
 $strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
 $strMIME_without = 'Les types MIME affiches en italiques ne possdent pas de fonctions de transformation.';
 $strModifications = 'Les modifications ont t sauvegardes.';
-$strModifyIndexTopic = 'Modifier une clef';
+$strModifyIndexTopic = 'Modifier un index';
 $strModify = 'Modifier';
+$strMoveMenu = 'Dplacer le menu';
 $strMoveTable = '<b>Dplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
 $strMoveTableOK = 'La table %s a t dplace vers %s.';
 $strMoveTableSameNames = 'On ne peut dplacer la table sur elle-mme!';
@@ -478,6 +480,7 @@ $strMyISAMSortBufferSize = 'Taille de la mmoire tampon';
 $strMySQLCharset = 'Jeu de caractres pour MySQL';
 $strMysqlClientVersion = 'Version du client MySQL';
 $strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
+$strMysqlLibDiffersServerVersion = 'La version de votre bibliothque MySQL (%s) diffre de la version de votre serveur MySQL (%s). Ceci peut occasionner un comportement imprvisible.';
 $strMySQLSaid = 'MySQL a rpondu:';
 $strMySQLShowProcess = 'Afficher les processus';
 $strMySQLShowStatus = 'Afficher l\'tat du serveur';
@@ -495,8 +498,8 @@ $strNoDropDatabases = 'La commande "DROP DATABASE" est dsactive.';
 $strNoExplain = 'Ne pas expliquer SQL';
 $strNoFilesFoundInZip = 'Aucun fichier prsent dans l\'archive ZIP!';
 $strNoFrames = 'L\'utilisation de phpMyAdmin est plus aise avec un navigateur <b>supportant les "frames"</b>.';
-$strNoIndex = 'Aucune clef n\'est dfinie&nbsp;!';
-$strNoIndexPartsDefined = 'Aucune colonne n\'a t dfinie pour cette clef&nbsp;!';
+$strNoIndex = 'Aucun index n\'est dfini&nbsp;!';
+$strNoIndexPartsDefined = 'Aucune colonne n\'a t dfinie pour cet index&nbsp;!';
 $strNoModification = 'Pas de modifications';
 $strNone = 'aucune';
 $strNo = 'Non';
@@ -517,19 +520,19 @@ $strNoUsersFound = 'Il n\'y a aucun utilisateur';
 $strNoValidateSQL = 'Ne pas valider SQL';
 $strNull = 'Null';
 $strNumberOfFields = 'Nombre de champs';
+$strNumberOfTables = 'Nombre de tables';
 $strNumSearchResultsInTable = '%s occurence(s) dans la table <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Options pour tableur "Open Document"';
 $strOpenDocumentSpreadsheet = 'Tableur "Open Document"';
-$strOpenDocumentTextOptions = 'Options pour texte "Open Document"';
 $strOpenDocumentText = 'Texte "Open Document"';
 $strOpenNewWindow = 'Ouvrir une nouvelle fentre phpMyAdmin';
 $strOperations = 'Oprations';
 $strOperator = 'Oprateur';
 $strOptimizeTable = 'Optimiser la table';
+$strOptions = 'Options';
 $strOr = 'Ou';
 $strOverhead = 'Perte';
 $strOverwriteExisting = 'craser les fichiers existants';
@@ -547,7 +550,6 @@ $strPasswordNotSame = 'Les mots de passe doivent tre identiques';
 $strPdfDbSchema = 'Schema de la base "%s" - Page %s';
 $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
-$strPDFOptions = 'Options PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Gnre un rapport contenant les donnes d\'une seule table)';
 $strPDFReportTitle = 'Titre du rapport';
@@ -559,15 +561,17 @@ $strPhoneBook = 'annuaire tlphonique';
 $strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un srieux problme avec les caractres multi-octets (mbstring), tel que dcrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommand d\'utiliser cette version de PHP avec phpMyAdmin.';
 $strPhp = 'Crer source PHP';
 $strPHPVersion = 'Version de PHP';
+$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la cl primaire ou un index unique';
 $strPmaDocumentation = 'Documentation de phpMyAdmin';
 $strPmaUriError = 'Le paramtre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT tre renseign dans votre fichier de configuration !';
+$strPmaWiki = 'Wiki phpMyAdmin';
 $strPolish = 'polonais';
 $strPortrait = 'Portrait';
 $strPos1 = 'Dbut';
 $strPrevious = 'Prcdent';
 $strPrimaryKeyHasBeenDropped = 'La cl primaire a t efface';
-$strPrimaryKeyName = 'Le nom d\'une clef primaire doit tre PRIMARY&nbsp;!';
-$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut tre</b> que le nom d\'une clef primaire&nbsp;!)';
+$strPrimaryKeyName = 'Le nom d\'une cl primaire doit tre PRIMARY!';
+$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut tre</b> que le nom d\'une cl primaire&nbsp;!)';
 $strPrimary = 'Primaire';
 $strPrint = 'Imprimer';
 $strPrintViewFull = 'Version imprimable (avec textes complets)';
@@ -613,6 +617,7 @@ $strPrivilegesReloaded = 'Les privilges ont t rechargs.';
 $strProcedures = 'Procdures';
 $strProcesses = 'Processus';
 $strProcesslist = 'Liste des processus';
+$strProfiling = 'Profilage';
 $strProtocolVersion = 'Version du protocole';
 $strPutColNames = 'Afficher les noms de champ en premire ligne';
 
@@ -625,22 +630,25 @@ $strQueryOnDb = 'Requte SQL sur la base <b>%s</b>&nbsp;:';
 $strQueryResultsOperations = 'Oprations sur les rsultats de la requte';
 $strQuerySQLHistory = 'Historique SQL';
 $strQueryStatistics = '<b>Statistiques sur les requtes</b>: Depuis son dmarrage, %s requtes ont t envoyes au serveur.';
-$strQueryTime = 'traitement: %01.4f sec.';
+$strQueryTime = 'Traitement en %01.4f sec.';
 $strQueryType = 'Type de requte';
 $strQueryWindowLock = 'Ne pas craser cette requte depuis une autre fentre';
 
 $strReadRequests = 'Requtes de lecture';
 $strReceived = 'Reu';
+$strRecommended = 'recommand';
 $strRecords = 'Enregistrements';
 $strReferentialIntegrity = 'Vrifier l\'intgrit rfrentielle';
 $strRefresh = 'Actualiser';
 $strRelationalSchema = 'Schma relationnel';
+$strRelationDeleted = 'Relation supprime';
 $strRelationNotWorking = 'Certaines fonctionnalits ayant trait aux tables relies sont dsactives. Pour une analyse du problme, cliquez %sici%s.';
 $strRelationsForTable = 'RELATIONS POUR LA TABLE';
 $strRelations = 'Relations';
 $strRelationView = 'Gestion des relations';
 $strReloadingThePrivileges = 'Chargement des privilges en cours.';
 $strReloadPrivileges = 'Recharger les privilges';
+$strReload = 'Recharger';
 $strRemoveSelectedUsers = 'Effacer les utilisateurs slectionns.';
 $strRenameDatabaseOK = 'La base de donnes %s a t renomme en %s';
 $strRenameTable = '<b>Changer le nom</b> de la table pour';
@@ -651,12 +659,15 @@ $strReplaceTable = 'Remplacer les donnes de la table avec le fichier';
 $strReplication = 'Rplication';
 $strReset = 'Rinitialiser les valeurs';
 $strResourceLimits = 'Limites de ressources.';
+$strRestartInsertion = 'Recommencer l\'insertion avec %s lignes';
 $strReType = 'Entrer  nouveau';
 $strRevokeAndDeleteDescr = 'Les utilisateurs auront le privilege "USAGE", jusqu\' ce que les privilges soient rechargs.';
 $strRevokeAndDelete = 'Effacer tous les privilges de ces utilisateurs, puis les effacer.';
 $strRevokeMessage = 'Vous avez rvoqu les privilges pour %s';
 $strRevoke = 'Rvoquer';
 $strRomanian = 'roumain';
+$strRoutineReturnType = 'Type retourn';
+$strRoutines = 'Procdures stockes';
 $strRowLength = 'Longueur enr.';
 $strRows = 'Enregistrements';
 $strRowsFrom = 'enregistrement(s)  partir de l\'enregistrement n';
@@ -673,6 +684,7 @@ $strRunSQLQueryOnServer = 'Excuter une ou des requtes SQL sur le serveur %s';
 $strRussian = 'russe';
 
 $strSaveOnServer = 'Sauvegarder sur le serveur dans le rpertoire %s';
+$strSavePosition = 'Sauvegarder la position';
 $strSave = 'Sauvegarder';
 $strScaleFactorSmall = 'Veuillez augmenter l\'chelle car le schma dborde la page';
 $strSearchFormTitle = 'Effectuer une nouvelle recherche dans la base de donnes';
@@ -690,7 +702,9 @@ $strSelectADb = 'Choisissez une base de donnes';
 $strSelectAll = 'Tout slectionner';
 $strSelectBinaryLog = 'Slectionnez le log binaire  consulter';
 $strSelectFields = 'Choisir les champs  afficher (au moins un)';
+$strSelectForeignKey = 'Choisissez la cl trangre';
 $strSelectNumRows = 'dans la requte';
+$strSelectReferencedKey = 'Slectionnez la cl rfrence';
 $strSelectTables = 'Choisissez les tables';
 $strSend = 'Transmettre';
 $strSent = 'Envoy';
@@ -705,6 +719,7 @@ $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Statistiques sur le trafic</b>: Ce tableau indique le trafic rseau observ sur ce serveur MySQL depuis son dmarrage.';
 $strServerVars = 'Variables et rglages du serveur';
 $strServerVersion = 'Version du serveur';
+$strSessionStartupErrorGeneral = 'Erreur lors du dmarrage de la session, veuillez vrifier les erreurs indiques par PHP ou dans le fichier tmoin du serveur web, et configurer PHP correctement.';
 $strSessionValue = 'Valeur pour la session';
 $strSetEnumVal = 'Les diffrentes valeurs des champs de type enum/set sont  spcifier sous la forme \'a\',\'b\',\'c\'...<br />Pour utiliser un caractre "\\" ou "\'" dans l\'une de ces valeurs, faites-le prcder du caractre d\'chappement "\\" (par exemple \'\\\\xyz\' ou \'a\\\'b\').';
 $strShow = 'Afficher';
@@ -713,8 +728,11 @@ $strShowColor = 'Couleurs';
 $strShowDatadictAs = 'Orientation du dictionnaire:';
 $strShowFullQueries = 'Afficher les requtes compltes';
 $strShowGrid = 'Grille';
+$strShowHideLeftMenu = 'Montrer/cacher le menu de gauche';
 $strShowingBookmark = 'Affichage du signet';
+$strShowingPhp = 'Affichage du code PHP';
 $strShowingRecords = 'Affichage des enregistrements';
+$strShowingSQL = 'Affichage de la requte SQL';
 $strShowOpenTables = 'Montrer les tables ouvertes';
 $strShowPHPInfo = 'Afficher les informations relatives  PHP';
 $strShowSlaveHosts = 'Montrer les serveurs esclaves';
@@ -791,7 +809,7 @@ $strShowStatusKey_readsDescr = 'Le nombre de lectures physiques d\'un bloc de cl
 $strShowStatusKey_write_requestsDescr = 'Le nombre de requtes en vue d\'crire un bloc de cl dans la cache.';
 $strShowStatusKey_writesDescr = 'Le nombre d\'critures physiques d\'un bloc de cls vers le disque.';
 $strShowStatusLast_query_costDescr = 'Le cot total de la dernire requte compile, tel que calcul par l\'optimiseur de requtes. Utile pour comparer le cot de diverses stratgies pour une mme requte. La valeur de 0 indique qu\'aucune requte n\'a encore t compile.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'criture (INSERT DELAY).';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'criture (INSERT DELAYED).';
 $strShowStatusOpened_tablesDescr = 'Le nombre tables qui ont t ouvertes. Si trop lev, votre cache de table est probablement trop petite.';
 $strShowStatusOpen_filesDescr = 'Le nombre de fichiers qui sont ouverts.';
 $strShowStatusOpen_streamsDescr = 'Le nombre de flux de donnes qui sont ouverts.';
@@ -835,6 +853,8 @@ $strSize = 'Taille';
 $strSkipQueries = 'Nombre d\'enregistrements (requtes)  ignorer  partir du dbut';
 $strSlovak = 'slovaque';
 $strSlovenian = 'slovne';
+$strSmallBigAll = 'Agrandir/rduire tout';
+$strSnapToGrid = 'Accrocher  la grille';
 $strSocketProblem = '(ou l\'interface de connexion ("socket") vers le serveur MySQL local n\'est pas correctement configure)';
 $strSortByKey = 'Trier sur l\'index';
 $strSorting = 'Mcanisme de tri';
@@ -844,8 +864,6 @@ $strSpanish = 'espagnol';
 $strSplitWordsWithSpace = 'Sparer les mots par un espace (" ").';
 $strSQLCompatibility = 'Mode de compatibilit SQL';
 $strSQLExportType = 'Type d\'exportation';
-$strSQLImportOptions = 'Options SQL';
-$strSQLOptions = 'options SQL';
 $strSQLParserBugMessage = 'Il semble que vous ayiez trouv une anomalie dans l\'analyseur syntaxique SQL. Veuillez examiner votre requte attentivement, et vrifier que vos apostrophes sont conformes. Il se pourrait aussi que vous ayiez charg un fichier dont le contenu binaire n\'est pas entre apostrophes.  Si vous avez accs  MySQL via son interface de commande en mode ligne, vous pouvez y essayer votre requte. Le message d\'erreur prsent plus bas pourrait vous indiquer la source du problme. En dernier recours, veuillez trouver la plus courte requte possible qui cause le problme, et soumettre un rapport d\'anomalie en incluant la section  couper:';
 $strSQLParserUserError = 'Il semble qu\'il y ait une erreur dans votre requte SQL. Le message ci-bas peut vous aider  en trouver la cause.';
 $strSQLQuery = 'requte SQL';
@@ -854,6 +872,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Identificateur invalide';
 $strSQPBugUnclosedQuote = 'Apostrophe non ferm';
 $strSQPBugUnknownPunctuation = 'Ponctuation invalide';
+$strStandInStructureForView = 'Doublure de structure pour la vue';
 $strStatCheckTime = 'Dernire vrification';
 $strStatCreateTime = 'Cration';
 $strStatement = 'Information';
@@ -866,9 +885,9 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Structure et donnes';
 $strStrucExcelCSV = 'CSV pour MS Excel';
 $strStrucNativeExcel = 'Donnes MS Excel (format natif)';
-$strStrucNativeExcelOptions = 'Options pour Excel natif';
 $strStrucOnly = 'Structure seule';
 $strStructPropose = 'Suggrer des optimisations quant  la structure de la table';
+$strStructureForView = 'Structure de la vue';
 $strStructure = 'Structure';
 $strSubmit = 'Excuter';
 $strSuccess = 'Votre requte SQL a t excute avec succs';
@@ -883,7 +902,9 @@ $strTableEmpty = 'Le nom de la table est vide';
 $strTableHasBeenDropped = 'La table %s a t efface';
 $strTableHasBeenEmptied = 'La table %s a t vide';
 $strTableHasBeenFlushed = 'La table %s a t recharge';
+$strTableIsEmpty = 'La table semble vide!';
 $strTableMaintenance = '<b>Maintenance</b> de la table';
+$strTableName = 'Nom de la table';
 $strTableOfContents = 'Table des matires';
 $strTableOptions = '<b>Options</b> pour cette table';
 $strTables = '%s table(s)';
@@ -901,14 +922,16 @@ $strThemeNoValidImgPath = 'Chemin des images inexistant pour le thme %s!';
 $strThemePathNotFound = 'Chemin non trouv pour le thme %s!';
 $strTheme = 'Thme / Style';
 $strThisHost = 'Ce serveur';
-$strThisNotDirectory = 'Ceci n\'est pas un rpertoire';
 $strThreads = 'Fils d\'excution';
 $strThreadSuccessfullyKilled = 'Le processus %s a t limin.';
 $strTime = 'Dure';
 $strTimeoutInfo = 'L\'importation prcdente a chou en raison du temps; retransmettez et le traitement reprendra  la position %d.';
 $strTimeoutNothingParsed = 'Cependant lors du dernier traitement, aucune section n\a t analyse; ceci signifie que phpMyAdmin ne pourra terminer cette importation,  moins que la limite de temps de PHP ne soit augmente';
 $strTimeoutPassed = 'La limite de temps a t atteinte; si vous voulez terminer l\'importation, soumettez  nouveau le mme fichier et l\'importation continuera.';
+$strToFromPage = 'de/vers la page';
 $strToggleScratchboard = 'diteur visuel';
+$strToggleSmallBig = 'Bascule agrandir/rduire';
+$strToSelectRelation = 'Pour slectionner un lien, cliquez :';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'chinois traditionnel';
@@ -920,13 +943,14 @@ $strTransformation_application_octetstream__hex = 'Affiche une reprsentation hex
 $strTransformation_image_jpeg__inline = 'Affiche une image timbre-poste cliquable; les options sont: largeur,hauteur en pixels (conserve le rapport original)';
 $strTransformation_image_jpeg__link = 'Affiche un lien vers cette image';
 $strTransformation_image_png__inline = 'Voir image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Change le format des champs de type TIME, TIMESTAMP ou DATETIME selon votre format local de date/heure. La premire option est le dcalage horaire qui sera ajout (par dfaut 0). La seconde option est un format en accord avec les paramtres de la fonction PHP strftime().';
+$strTransformation_text_plain__dateformat = 'Affiche un champ TIME, TIMESTAMP, DATETIME ou un champ numrique contenant une valeur TIMESTAMP UNIX en tant que date formate. La premire option est le dcalage (en heures)  ajouter (par dfaut, 0). La seconde option sert  indiquer le format de date ou d\'heure. La troisime option dtermine si vous voulez la date locale ("local") ou UTC ("utc"). Pour le format "local", le second paramtre utilise le format de la fonction PHP strftime() et pour le format "utc", il utilise la fonction gmdate().';
 $strTransformation_text_plain__external = '(Linux seulement) Excute un programme externe et lui envoit le contenu du champ via l\'entre standard. Puis capture la sortie standard de ce programme externe. Le programme par dfaut est tidy, pour un affichage embelli du code HTML.  Pour des raisons de scurit, vous devez diter le script libraries/transformations/text_plain__external.inc.php et y insrer les noms de programme externe possibles. La premire option est le numro du programme que vous voulez utiliser, la seconde option contient les paramtres pour ce programme. En troisime option, une valeur de 1 va convertir le rsultat avec la fonction htmlspecialchars() (par dfaut, 1). En option 4, une valeur de 1 va ajouter NOWRAP  la cellule affiche (par dfaut, 1).';
 $strTransformation_text_plain__formatted = 'Prserve le contenu original du champ, sans ajout de caractres d\'chappement.';
 $strTransformation_text_plain__imagelink = 'Affiche une image et un lien, le champ contient le nom du fichier; en premire option, un prfixe comme "http://domaine.com/", en seconde option, la largeur en pixels, en troisime option la hauteur en pixels.';
 $strTransformation_text_plain__link = 'Affiche un lien, le champ contient le nom du fichier; en premire option, un prfixe comme "http://domaine.com/", en seconde option, un titre pour le lien.';
 $strTransformation_text_plain__sql = 'Affiche le texte comme une requte SQL avec embellissement de la syntaxe.';
 $strTransformation_text_plain__substr = 'N\'affiche qu\'une partie du champ. En premire option, la position de dpart (par dfaut, 0). En seconde option, le nombre de caractres  afficher (par dfaut, le reste). En troisime option, des caractres  afficher  la fin du texte (par dfaut: "...").';
+$strTriggers = 'Dclencheurs';
 $strTruncateQueries = 'Afficher les requtes tronques';
 $strTurkish = 'turc';
 $strType = 'Type';
@@ -943,6 +967,13 @@ $strUpdateProfileMessage = 'Le profil a t modifi.';
 $strUpdateQuery = 'Mise--jour de la requte';
 $strUpdComTab = 'La documentation indique comment mettre  jour votre table Column_comments';
 $strUpgrade = 'Vous devriez utiliser %s en version %s ou plus rcente.';
+$strUploadErrorCantWrite = 'Erreur lors de l\'criture du fichier sur disque.';
+$strUploadErrorExtension = 'Tlchargement arrt par l\'extension.';
+$strUploadErrorFormSize = 'La taille du fichier tlcharg dpasse la limite permise par la directive MAX_FILE_SIZE prsente dans le formulaire HTML.';
+$strUploadErrorIniSize = 'La taille du fichier tlcharg dpasse la limite permise par la directive upload_max_filesize de php.ini.';
+$strUploadErrorNoTempDir = 'Rpertoire temporaire manquant.';
+$strUploadErrorPartial = 'Le fichier n\'a t que partiellement tlcharg.';
+$strUploadErrorUnknown = 'Erreur inconnue durant le tlchargement.';
 $strUploadLimit = 'Vous avez probablement tent de tlcharger un fichier trop volumineux. Veuillez vous rfrer  la %sdocumentation%s pour des faons de contourner cette limite.';
 $strUploadsNotAllowed = 'Les tlchargements vers ce serveur ne sont pas permis.';
 $strUsage = 'Espace';
@@ -972,6 +1003,7 @@ $strViewDumpDatabases = 'Schma et/ou contenu des bases de donnes';
 $strViewDumpDB = 'Schma et donnes de la base ';
 $strViewHasBeenDropped = 'La vue %s a t supprime';
 $strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous rfrer  la %sdocumentation%s.';
+$strViewName = 'Nom de la vue';
 $strView = 'Vue';
 
 $strWebServerUploadDirectoryError = 'Le rpertoire de transfert est inaccessible';
@@ -982,11 +1014,8 @@ $strWildcard = 'passepartout';
 $strWindowNotFound = 'La fentre principale n\'a pu tre mise  jour. Il est possible que vous l\'ayiez ferme, ou encore que votre navigateur bloque les mises  jour inter-fentres pour des raisons de scurit.';
 $strWithChecked = 'Pour la slection :';
 $strWriteRequests = 'Requtes d\'criture';
-$strWritingCommentNotPossible = 'Ajout de commentaire impossible';
-$strWritingRelationNotPossible = 'Ajout de relation impossible';
 $strWrongUser = 'Erreur d\'utilisateur/mot de passe. Accs refus';
 
-$strXMLOptions = 'Options XML';
 $strXML = 'XML';
 
 $strYes = 'Oui';
@@ -994,4 +1023,5 @@ $strYes = 'Oui';
 $strZeroRemovesTheLimit = 'Note: Une valeur de 0 (zero) enlve la limite.';
 $strZip = '"zipp"';
 
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
